==> helm-annotations-3.5.0-sources.jar: io/dekorate/helm/config/AddIfStatementFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddIfStatementFluentImpl<A extends AddIfStatementFluent<A>> extends BaseFluent<A> implements AddIfStatementFluent<A>{
  public AddIfStatementFluentImpl() {
  }
  public AddIfStatementFluentImpl(AddIfStatement instance) {
    this.withProperty(instance.getProperty()); 
    this.withOnResourceKind(instance.getOnResourceKind()); 
    this.withOnResourceName(instance.getOnResourceName()); 
    this.withWithDefaultValue(instance.getWithDefaultValue()); 
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  public String getProperty() {
    return this.property;
  }
  public A withProperty(String property) {
    this.property=property; return (A) this;
  }
  public Boolean hasProperty() {
    return this.property != null;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public A withOnResourceKind(String onResourceKind) {
    this.onResourceKind=onResourceKind; return (A) this;
  }
  public Boolean hasOnResourceKind() {
    return this.onResourceKind != null;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public A withOnResourceName(String onResourceName) {
    this.onResourceName=onResourceName; return (A) this;
  }
  public Boolean hasOnResourceName() {
    return this.onResourceName != null;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public A withWithDefaultValue(Boolean withDefaultValue) {
    this.withDefaultValue=withDefaultValue; return (A) this;
  }
  public Boolean hasWithDefaultValue() {
    return this.withDefaultValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddIfStatementFluentImpl that = (AddIfStatementFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (onResourceKind != null ? !onResourceKind.equals(that.onResourceKind) :that.onResourceKind != null) return false;
    if (onResourceName != null ? !onResourceName.equals(that.onResourceName) :that.onResourceName != null) return false;
    if (withDefaultValue != null ? !withDefaultValue.equals(that.withDefaultValue) :that.withDefaultValue != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (property != null) { sb.append("property:"); sb.append(property + ","); }
    if (onResourceKind != null) { sb.append("onResourceKind:"); sb.append(onResourceKind + ","); }
    if (onResourceName != null) { sb.append("onResourceName:"); sb.append(onResourceName + ","); }
    if (withDefaultValue != null) { sb.append("withDefaultValue:"); sb.append(withDefaultValue); }
    sb.append("}");
    return sb.toString();
  }
  public A withWithDefaultValue() {
    return withWithDefaultValue(true);
  }
  
}

==> helm-annotations-3.7.6-sources.jar: io/dekorate/helm/config/AddIfStatementFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddIfStatementFluentImpl<A extends AddIfStatementFluent<A>> extends BaseFluent<A> implements AddIfStatementFluent<A>{
  public AddIfStatementFluentImpl() {
  }
  public AddIfStatementFluentImpl(AddIfStatement instance) {
    this.withProperty(instance.getProperty()); 
    this.withOnResourceKind(instance.getOnResourceKind()); 
    this.withOnResourceName(instance.getOnResourceName()); 
    this.withWithDefaultValue(instance.getWithDefaultValue()); 
    this.withDescription(instance.getDescription()); 
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  public String getProperty() {
    return this.property;
  }
  public A withProperty(String property) {
    this.property=property; return (A) this;
  }
  public Boolean hasProperty() {
    return this.property != null;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public A withOnResourceKind(String onResourceKind) {
    this.onResourceKind=onResourceKind; return (A) this;
  }
  public Boolean hasOnResourceKind() {
    return this.onResourceKind != null;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public A withOnResourceName(String onResourceName) {
    this.onResourceName=onResourceName; return (A) this;
  }
  public Boolean hasOnResourceName() {
    return this.onResourceName != null;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public A withWithDefaultValue(Boolean withDefaultValue) {
    this.withDefaultValue=withDefaultValue; return (A) this;
  }
  public Boolean hasWithDefaultValue() {
    return this.withDefaultValue != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddIfStatementFluentImpl that = (AddIfStatementFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (onResourceKind != null ? !onResourceKind.equals(that.onResourceKind) :that.onResourceKind != null) return false;
    if (onResourceName != null ? !onResourceName.equals(that.onResourceName) :that.onResourceName != null) return false;
    if (withDefaultValue != null ? !withDefaultValue.equals(that.withDefaultValue) :that.withDefaultValue != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (property != null) { sb.append("property:"); sb.append(property + ","); }
    if (onResourceKind != null) { sb.append("onResourceKind:"); sb.append(onResourceKind + ","); }
    if (onResourceName != null) { sb.append("onResourceName:"); sb.append(onResourceName + ","); }
    if (withDefaultValue != null) { sb.append("withDefaultValue:"); sb.append(withDefaultValue + ","); }
    if (description != null) { sb.append("description:"); sb.append(description); }
    sb.append("}");
    return sb.toString();
  }
  public A withWithDefaultValue() {
    return withWithDefaultValue(true);
  }
  
}
